# docusign-maestro
Maestro authors and executes experiences that allow non-coders the ability to define Simple Business Process without having to write code and to deploy them seamlessly without having to have development expertise

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 1.0.0
- Package version: 1.0.0
- Build package: io.swagger.codegen.languages.PythonClientCodegen
For more information, please visit [https://developers.docusign.com/](https://developers.docusign.com/)

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import docusign_maestro 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import docusign_maestro
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import docusign_maestro
from docusign_maestro.rest import ApiException
from pprint import pprint

# Configure OAuth2 access token for authorization: docusignAccessCode
configuration = docusign_maestro.Configuration()
configuration.access_token = 'YOUR_ACCESS_TOKEN'

# create an instance of the API class
api_instance = docusign_maestro.WorkflowInstanceManagementApi(docusign_maestro.ApiClient(configuration))
account_id = 'account_id_example' # str | Account ID
instance_id = 'instance_id_example' # str | DS Workflow Instance Id (dacId)

try:
    # Cancels a running workflow instance.
    api_response = api_instance.cancel_workflow_instance(account_id, instance_id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling WorkflowInstanceManagementApi->cancel_workflow_instance: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://www.docusign.net*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*WorkflowInstanceManagementApi* | [**cancel_workflow_instance**](docs/WorkflowInstanceManagementApi.md#cancel_workflow_instance) | **POST** aow-manage/v1.0/management/accounts/{accountId}/instances/{instanceId}/cancel | Cancels a running workflow instance.
*WorkflowInstanceManagementApi* | [**get_workflow_history**](docs/WorkflowInstanceManagementApi.md#get_workflow_history) | **GET** aow-manage/v1.0/management/accounts/{accountId}/instances/{instanceId}/history | Get List of Step Histories
*WorkflowInstanceManagementApi* | [**get_workflow_instance**](docs/WorkflowInstanceManagementApi.md#get_workflow_instance) | **GET** aow-manage/v1.0/management/accounts/{accountId}/workflowDefinitions/{workflowDefinitionId}/instances/{instanceId} | Get Workflow Instance Details
*WorkflowInstanceManagementApi* | [**get_workflow_instances**](docs/WorkflowInstanceManagementApi.md#get_workflow_instances) | **GET** aow-manage/v1.0/management/accounts/{accountId}/workflowDefinitions/{workflowDefinitionId}/instances | Get List of Workflow Instances
*WorkflowManagementApi* | [**create_workflow_definition**](docs/WorkflowManagementApi.md#create_workflow_definition) | **POST** aow-manage/v1.0/management/accounts/{accountId}/workflowDefinitions | Creates a new workflow definition.
*WorkflowManagementApi* | [**delete_workflow_definition**](docs/WorkflowManagementApi.md#delete_workflow_definition) | **DELETE** aow-manage/v1.0/management/accounts/{accountId}/workflowDefinitions/{workflowDefinitionId} | Deletes a workflow definition.
*WorkflowManagementApi* | [**get_workflow_definition**](docs/WorkflowManagementApi.md#get_workflow_definition) | **GET** aow-manage/v1.0/management/accounts/{accountId}/workflowDefinitions/{workflowDefinitionId} | Get Workflow Definition
*WorkflowManagementApi* | [**get_workflow_definition_config_instances**](docs/WorkflowManagementApi.md#get_workflow_definition_config_instances) | **GET** aow-manage/v1.0/management/accounts/{accountId}/workflowDefinitions/{workflowDefinitionId}/configInstances | Gets configuration instances
*WorkflowManagementApi* | [**get_workflow_definitions**](docs/WorkflowManagementApi.md#get_workflow_definitions) | **GET** aow-manage/v1.0/management/accounts/{accountId}/workflowDefinitions | Get Workflow Definitions metadata
*WorkflowManagementApi* | [**publish_or_un_publish_workflow_definition**](docs/WorkflowManagementApi.md#publish_or_un_publish_workflow_definition) | **POST** aow-manage/v1.0/management/accounts/{accountId}/workflowDefinitions/{workflowDefinitionId}/publish | Publishes or unpublishes a workflow definition.
*WorkflowManagementApi* | [**update_workflow_definition**](docs/WorkflowManagementApi.md#update_workflow_definition) | **PUT** aow-manage/v1.0/management/accounts/{accountId}/workflowDefinitions/{workflowDefinitionId} | Updates a workflow definition.
*WorkflowTriggerApi* | [**trigger_workflow**](docs/WorkflowTriggerApi.md#trigger_workflow) | **POST** aow-auth/v1.0/accounts/{accountId}/workflows/trigger | Creates a new workflow instance after authenticating with DS Account Server


## Documentation For Models

 - [AccessTokenResponse](docs/AccessTokenResponse.md)
 - [AccessTokenTokenTypes](docs/AccessTokenTokenTypes.md)
 - [CancelResponse](docs/CancelResponse.md)
 - [CreateOrUpdateWorkflowDefinitionRequestBody](docs/CreateOrUpdateWorkflowDefinitionRequestBody.md)
 - [DSDoUntilStep](docs/DSDoUntilStep.md)
 - [DSDocGenStep](docs/DSDocGenStep.md)
 - [DSDocGenStepInput](docs/DSDocGenStepInput.md)
 - [DSIdvStep](docs/DSIdvStep.md)
 - [DSIdvStepInput](docs/DSIdvStepInput.md)
 - [DSIfElseStep](docs/DSIfElseStep.md)
 - [DSLoopStep](docs/DSLoopStep.md)
 - [DSParallelStep](docs/DSParallelStep.md)
 - [DSServiceStep](docs/DSServiceStep.md)
 - [DSSignStep](docs/DSSignStep.md)
 - [DSSignStepInput](docs/DSSignStepInput.md)
 - [DSTransformationStep](docs/DSTransformationStep.md)
 - [DSWebFormsStep](docs/DSWebFormsStep.md)
 - [DSWebFormsStepConfig](docs/DSWebFormsStepConfig.md)
 - [DSWorkflowBooleanExpression](docs/DSWorkflowBooleanExpression.md)
 - [DSWorkflowComparisonExpression](docs/DSWorkflowComparisonExpression.md)
 - [DSWorkflowComparisonOperatorTypes](docs/DSWorkflowComparisonOperatorTypes.md)
 - [DSWorkflowConcatExpression](docs/DSWorkflowConcatExpression.md)
 - [DSWorkflowDocGenDocOutputFormat](docs/DSWorkflowDocGenDocOutputFormat.md)
 - [DSWorkflowExpressionTypesBooleanExpression](docs/DSWorkflowExpressionTypesBooleanExpression.md)
 - [DSWorkflowExpressionTypesComparisonExpression](docs/DSWorkflowExpressionTypesComparisonExpression.md)
 - [DSWorkflowExpressionTypesParallelExpression](docs/DSWorkflowExpressionTypesParallelExpression.md)
 - [DSWorkflowIndexOfExpression](docs/DSWorkflowIndexOfExpression.md)
 - [DSWorkflowLane](docs/DSWorkflowLane.md)
 - [DSWorkflowLanesRecord](docs/DSWorkflowLanesRecord.md)
 - [DSWorkflowLastIndexOfExpression](docs/DSWorkflowLastIndexOfExpression.md)
 - [DSWorkflowLogicalOperatorTypes](docs/DSWorkflowLogicalOperatorTypes.md)
 - [DSWorkflowParallelExpression](docs/DSWorkflowParallelExpression.md)
 - [DSWorkflowParticipantRecord](docs/DSWorkflowParticipantRecord.md)
 - [DSWorkflowReplaceExpression](docs/DSWorkflowReplaceExpression.md)
 - [DSWorkflowStep](docs/DSWorkflowStep.md)
 - [DSWorkflowStepTypesDSDocGen](docs/DSWorkflowStepTypesDSDocGen.md)
 - [DSWorkflowStepTypesDSIdv](docs/DSWorkflowStepTypesDSIdv.md)
 - [DSWorkflowStepTypesDSIfElse](docs/DSWorkflowStepTypesDSIfElse.md)
 - [DSWorkflowStepTypesDSSign](docs/DSWorkflowStepTypesDSSign.md)
 - [DSWorkflowStepTypesDSTransformation](docs/DSWorkflowStepTypesDSTransformation.md)
 - [DSWorkflowStepTypesDSWebForms](docs/DSWorkflowStepTypesDSWebForms.md)
 - [DSWorkflowStepTypesDoUntil](docs/DSWorkflowStepTypesDoUntil.md)
 - [DSWorkflowStepTypesLoop](docs/DSWorkflowStepTypesLoop.md)
 - [DSWorkflowStepTypesParallel](docs/DSWorkflowStepTypesParallel.md)
 - [DSWorkflowSubstringExpression](docs/DSWorkflowSubstringExpression.md)
 - [DSWorkflowToLowerExpression](docs/DSWorkflowToLowerExpression.md)
 - [DSWorkflowToUpperExpression](docs/DSWorkflowToUpperExpression.md)
 - [DSWorkflowTransformationExpression](docs/DSWorkflowTransformationExpression.md)
 - [DSWorkflowTransformationExpressionTypesConcatExpression](docs/DSWorkflowTransformationExpressionTypesConcatExpression.md)
 - [DSWorkflowTransformationExpressionTypesIndexOfExpression](docs/DSWorkflowTransformationExpressionTypesIndexOfExpression.md)
 - [DSWorkflowTransformationExpressionTypesLastIndexOfExpression](docs/DSWorkflowTransformationExpressionTypesLastIndexOfExpression.md)
 - [DSWorkflowTransformationExpressionTypesReplaceExpression](docs/DSWorkflowTransformationExpressionTypesReplaceExpression.md)
 - [DSWorkflowTransformationExpressionTypesSubstringExpression](docs/DSWorkflowTransformationExpressionTypesSubstringExpression.md)
 - [DSWorkflowTransformationExpressionTypesToLowerExpression](docs/DSWorkflowTransformationExpressionTypesToLowerExpression.md)
 - [DSWorkflowTransformationExpressionTypesToUpperExpression](docs/DSWorkflowTransformationExpressionTypesToUpperExpression.md)
 - [DSWorkflowTrigger](docs/DSWorkflowTrigger.md)
 - [DSWorkflowTriggerTypes](docs/DSWorkflowTriggerTypes.md)
 - [DSWorkflowVariable](docs/DSWorkflowVariable.md)
 - [DSWorkflowVariableFromParticipant](docs/DSWorkflowVariableFromParticipant.md)
 - [DSWorkflowVariableFromStep](docs/DSWorkflowVariableFromStep.md)
 - [DSWorkflowVariableFromVariable](docs/DSWorkflowVariableFromVariable.md)
 - [DSWorkflowVariableRecord](docs/DSWorkflowVariableRecord.md)
 - [DSWorkflowVariableSourceTypesStep](docs/DSWorkflowVariableSourceTypesStep.md)
 - [DSWorkflowVariableSourceTypesVariable](docs/DSWorkflowVariableSourceTypesVariable.md)
 - [DeployRequest](docs/DeployRequest.md)
 - [DeployResponse](docs/DeployResponse.md)
 - [DeployStatus](docs/DeployStatus.md)
 - [DeploymentStatus](docs/DeploymentStatus.md)
 - [ESignDocumentFromESignTemplate](docs/ESignDocumentFromESignTemplate.md)
 - [ESignDocumentFromPreviousStep](docs/ESignDocumentFromPreviousStep.md)
 - [ESignDocumentTypesFromDSTemplate](docs/ESignDocumentTypesFromDSTemplate.md)
 - [ESignDocumentTypesFromPreviousStep](docs/ESignDocumentTypesFromPreviousStep.md)
 - [ESignDocuments](docs/ESignDocuments.md)
 - [ESignLocalePolicy](docs/ESignLocalePolicy.md)
 - [ESignSigner](docs/ESignSigner.md)
 - [ESignTabs](docs/ESignTabs.md)
 - [ESignTabsRecord](docs/ESignTabsRecord.md)
 - [ErrorCodes](docs/ErrorCodes.md)
 - [ErrorResponse](docs/ErrorResponse.md)
 - [EventTypes](docs/EventTypes.md)
 - [GetConfigurationInstanceResponse](docs/GetConfigurationInstanceResponse.md)
 - [GetConfigurationInstancesResponse](docs/GetConfigurationInstancesResponse.md)
 - [GetConfigurationInstancesResponseConfigInstances](docs/GetConfigurationInstancesResponseConfigInstances.md)
 - [HttpTypes](docs/HttpTypes.md)
 - [InvalidWorkflowResponse](docs/InvalidWorkflowResponse.md)
 - [NewOrUpdatedWorkflowDefinitionResponse](docs/NewOrUpdatedWorkflowDefinitionResponse.md)
 - [NumberOrVariable](docs/NumberOrVariable.md)
 - [Participant](docs/Participant.md)
 - [ProgressInstance](docs/ProgressInstance.md)
 - [RecordStringBoolean](docs/RecordStringBoolean.md)
 - [RecordStringOrVariableOrTransformation](docs/RecordStringOrVariableOrTransformation.md)
 - [RecordToNever](docs/RecordToNever.md)
 - [ReplicationStatus](docs/ReplicationStatus.md)
 - [StartedByInstance](docs/StartedByInstance.md)
 - [StringOrVariableOrTransformation](docs/StringOrVariableOrTransformation.md)
 - [SuccessMessageResponse](docs/SuccessMessageResponse.md)
 - [TriggerPayload](docs/TriggerPayload.md)
 - [TriggerWorkflowViaPostResponse](docs/TriggerWorkflowViaPostResponse.md)
 - [ValidationErrors](docs/ValidationErrors.md)
 - [WorkflowDefinition](docs/WorkflowDefinition.md)
 - [WorkflowDefinitionList](docs/WorkflowDefinitionList.md)
 - [WorkflowDefinitionMetadata](docs/WorkflowDefinitionMetadata.md)
 - [WorkflowDefinitionWithId](docs/WorkflowDefinitionWithId.md)
 - [WorkflowDeleteResponse](docs/WorkflowDeleteResponse.md)
 - [WorkflowInstance](docs/WorkflowInstance.md)
 - [WorkflowInstanceMap](docs/WorkflowInstanceMap.md)
 - [WorkflowInstanceState](docs/WorkflowInstanceState.md)
 - [WorkflowInstancesList](docs/WorkflowInstancesList.md)
 - [WorkflowMetadataStatus](docs/WorkflowMetadataStatus.md)
 - [WorkflowStepError](docs/WorkflowStepError.md)
 - [WorkflowStepErrorError](docs/WorkflowStepErrorError.md)
 - [WorkflowStepHistory](docs/WorkflowStepHistory.md)
 - [WorkflowStepHistoryList](docs/WorkflowStepHistoryList.md)
 - [WorkflowStepHistoryState](docs/WorkflowStepHistoryState.md)


## Documentation For Authorization


## docusignAccessCode

- **Type**: OAuth
- **Flow**: accessCode
- **Authorization URL**: https://account.docusign.com/oauth/auth
- **Scopes**: N/A


## Author

devcenter@docusign.com

